@@ -49,11 +49,11 @@ class GSPeerConnectionBroadcasterPiCaller:
     async def startSocket(self):
         self._logger.debug("start broadcast socket")
         await GSPeerConnectionBroadcasterPiSocketv2.create(self.sio,
-                                                         self.gsdbs,
-                                                         self.camera,
-                                                         self.oncommand,
-                                                         self.setChannel
-                                                         )
+                                                           self.gsdbs,
+                                                           self.camera,
+                                                           self.oncommand,
+                                                           self.setChannel
+                                                           )
 
 
 class GSPeerConnectionBroadcasterPiSocket:
@@ -238,10 +238,12 @@ class GSPeerConnectionBroadcasterPiSocket:
 def channel_log(logger, channel, t, message):
     logger.info("channel(%s) %s %s" % (channel.label, t, message))
 
+
 def channel_send(logger, channel, message):
     channel_log(logger, channel, ">", message)
     channel.send(message)
 
+
 class GSPeerConnectionBroadcasterPiSocketv2:
 
     def getPiH264Relay(self, id):
@@ -305,13 +307,10 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         self.webcam = None
         self.relay = None
 
-
-
         @self.sio.event
         async def connect():
             self._logger.info('connection established')
 
-
         @self.sio.event
         async def wjoined(id):
             await self.sio.emit("joined", self.sio.sid)
@@ -319,7 +318,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         @self.sio.event
         async def broadcaster(id, description):
 
-
             if len(self.rtconfiList) > 0:
                 pc = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
             else:
@@ -347,6 +345,9 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                     pc.addTrack(video)
 
             sendchannel = pc.createDataChannel("sendChannel")
+
+            if setChannel is not None:
+                setChannel(sendchannel)
             channel_log(self._logger, sendchannel, "-", "created by local party")
 
             @sendchannel.on("open")
@@ -369,8 +370,7 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                 if isinstance(message, str) and message.startswith('{"command'):
                     subprocess_cmd(json.loads(message)["command"])
 
-
-            await pc.setLocalDescription( await pc.createOffer())
+            await pc.setLocalDescription(await pc.createOffer())
 
             await self.sio.emit("watcher", {"target": description,
                                             "id": id,
@@ -390,7 +390,7 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                     await self.peerConnections[id].setRemoteDescription(answer)
 
         @self.sio.event
-        async def disconnectBroadcaster(id,desc):
+        async def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
                 self._logger.info("Disconnected Peer")
                 await self.peerConnections[id].close()
@@ -408,4 +408,4 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
         await self.sio.connect(
             f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}')
-        await self.sio.wait()
\ No newline at end of file
+        await self.sio.wait()
